const moment = require('moment');
const { KJUR } = require('jsrsasign');
const { v4: generateUuid } = require('uuid');

const EXP_DATE_FORMAT = 'YYYY-MM-DDTHH:mm:ss.SSSSSSSZ';

const basePayload = {
  name: "tferrell",
  roles: [
    "UCCost.Add",
    "UCCost.Delete",
    "UCCost.View",
    "UCCost.Modify"
  ],
  ip: "127.0.0.1",
  iss: "hlm-web",
  subs: ["UC"],
  aud: "hlm-cost"
};


const getEightHoursFromNowDate = () => {
  const time = moment();
  const currentHours = time.hours();

  return time
    .hours(currentHours + 8)
    .format(EXP_DATE_FORMAT);
};

const generateToken = (customerOwnerID, secret) => {
  const alg = 'HS256';
  const exp = getEightHoursFromNowDate();
  const iat = KJUR.jws.IntDate.get('now');
  const jti = generateUuid();

  const header = { alg, typ: 'JWT' };
  const payload = {
    ...basePayload,
    cust: customerOwnerID,
    exp,
    iat,
    jti,
  };

  const stringifiedHeader = JSON.stringify(header);
  const stringifiedPayload = JSON.stringify(payload);

  const signedToken = KJUR.jws.JWS.sign(alg, stringifiedHeader, stringifiedPayload, secret)

  return signedToken;
};

module.exports = generateToken;
