const http = require('http');

const parseURL = require('./parseURL');
const generateToken = require('./generateToken');

const DEFAULT_PORT = 3000;

const server = http.createServer((req, res) => {
  const urlData = parseURL(req.url);

  if (urlData.pathname === '/jwt' && req.method === 'GET') {
    const { customerOwnerId } = urlData.params;
    const { signingkey } = req.headers;

    if (!customerOwnerId) {
      res.statusCode = 400;
      res.end('"customerOwnerId" URL search param is required');
      return;
    }

    if (!signingkey) {
      res.statusCode = 400;
      res.end('"signingkey" request header is required');
      return;
    }

    const numericCustId = +customerOwnerId;
    const token = generateToken(numericCustId, signingkey);

    res.setHeader('Content-Type', 'text/plain');
    res.end(token);
  } else {
    res.statusCode = 404;
    res.end();
  }
});

server.listen(process.env.PORT || DEFAULT_PORT);
